#ifndef _LCD_H
#define _LCD_H

#define u08       unsigned char 
#define s08         signed char  
#define ui16       unsigned int  
#define si16         signed int  
#define uli32 unsigned long int 
#define sli32   signed long int 

//     888  565
#define RGB(r,g,b)  ((r & 0xF8) << 8) | ((g & 0xFC) << 3) | ((b & 0xF8) >> 3))

//   
#define BLACK                       RGB(0x00, 0x00, 0x00)  // for  8 bit colors R,G,B  3,3,2 Bits
#define WHITE                       RGB(0xFF, 0xFF, 0xFF)  // for 16 bit colors R,G,B  5,6,5 bits
#define RED                         RGB(0xFF, 0x00, 0x00)
#define GREEN                       RGB(0x00, 0xFF, 0x00)
#define BLUE                        RGB(0x00, 0x00, 0xFF)
#define YELLOW                      RGB(0xFF, 0xFF, 0x00)
#define MAGENTA                     RGB(0xFF, 0x00, 0xFF)
#define CYAN                        RGB(0x00, 0xFF, 0xFF)
#define GRAY                        RGB(0x80, 0x80, 0x40)
#define SILVER                      RGB(0xA0, 0xA0, 0x80)
#define GOLD                        RGB(0xA0, 0xA0, 0x40)

#define sky 0x54fb
#define black 0x0000
#define white 0xFFFF
#define green 0x07E0
#define blue 0x001F
#define red 0xF800
#define yellow 0xDEE0
#define orange 0xAB00
#define pink 0xF97F
#define brown 0x8200
#define grey 0x8410
#define violet 0x91D4

#define DATCTL 0xBC         // Data Control (data handling in RAM)
#define DISCTL 0xCA         // Display Control
#define GCP64 0xCB          // pulse set for 64 gray scale
#define GCP16 0xCC          // pulse set for 16 gray scale
#define OSSEL 0xD0          // Oscillator select
#define GSSET 0xCD          // set for gray scales
#define ASCSET 0xAA         // aerea scroll setting
#define SCSTART 0xAB        // scroll start setting
#define DISON 0xAF          // Display ON (no parameter)
#define DISOFF 0xAE         // Display OFF (no parameter)
#define DISINV 0xA7         // Display Invert (no parameter)
#define DISNOR 0xA6         // Display Normal (no parameter)
#define SLPIN  0x95         // Display Sleep (no parameter)
#define SLPOUT 0x94         // Display out of sleep (no parameter)
#define RAMWR 0x5C          // Display Memory write
#define PTLIN 0xA8          // partial screen write

#define SD_CSET 0x15        // column address setting
#define SD_PSET 0x75        // page address setting

void lcd_init();
void lcd_poweroff (void);

void put_string(unsigned char x, unsigned char y, char *str, unsigned int color, unsigned int bcolor, char m);
void lcd_rect(int x1, int y1, int x2, int y2, int color);
void lcd_circle(u08 xcenter, u08 ycenter, si16 rad, ui16 color);
void lcd_line ( int x1, int y1, int x2, int y2, unsigned int color );
void put_parametr(unsigned char x, unsigned char y, u08 flash*str1, int ch, u08 flash*str2, unsigned int color, unsigned int bcolor, char m);
void put_ch(unsigned char x, unsigned char y, int ch, unsigned int color, unsigned int bcolor, char m);
void put_str_fl(unsigned char x, unsigned char y, u08 flash*str, ui16 color, unsigned int bcolor, char m);
void put_char(char x, char y, char c, unsigned int color, unsigned int bcolor, char m);
void lcd_pixel (int x, int y, unsigned int color);
void lcd_fill(char x,char y,char w,char h,int color);
void fill_screen(unsigned int color);
void lcd_picture(unsigned char x, unsigned char y, unsigned char w, unsigned char h, flash unsigned int *pic);

#endif